==> payara-embedded-all-4.1.1.171.1-sources.jar: com/sun/enterprise/admin/monitor/stats/HAStatefulSessionStoreStats.java <==
/*
 * DO NOT ALTER OR REMOVE COPYRIGHT NOTICES OR THIS HEADER.
 *
 * Copyright (c) 1997-2011 Oracle and/or its affiliates. All rights reserved.
 *
 * The contents of this file are subject to the terms of either the GNU
 * General Public License Version 2 only ("GPL") or the Common Development
 * and Distribution License("CDDL") (collectively, the "License").  You
 * may not use this file except in compliance with the License.  You can
 * obtain a copy of the License at
 * https://glassfish.dev.java.net/public/CDDL+GPL_1_1.html
 * or packager/legal/LICENSE.txt.  See the License for the specific
 * language governing permissions and limitations under the License.
 *
 * When distributing the software, include this License Header Notice in each
 * file and include the License file at packager/legal/LICENSE.txt.
 *
 * GPL Classpath Exception:
 * Oracle designates this particular file as subject to the "Classpath"
 * exception as provided by Oracle in the GPL Version 2 section of the License
 * file that accompanied this code.
 *
 * Modifications:
 * If applicable, add the following below the License Header, with the fields
 * enclosed by brackets [] replaced by your own identifying information:
 * "Portions Copyright [year] [name of copyright owner]"
 *
 * Contributor(s):
 * If you wish your version of this file to be governed by only the CDDL or
 * only the GPL Version 2, indicate your decision by adding "[Contributor]
 * elects to include this software in this distribution under the [CDDL or GPL
 * Version 2] license."  If you don't indicate a single choice of license, a
 * recipient has the option to distribute your version of this file under
 * either the CDDL, the GPL Version 2 or to extend the choice of license to
 * its licensees as provided above.  However, if you add GPL Version 2 code
 * and therefore, elected the GPL Version 2 license, then the option applies
 * only if the new code is made subject to such option by the copyright
 * holder.
 */

package com.sun.enterprise.admin.monitor.stats;
import org.glassfish.j2ee.statistics.CountStatistic;
import org.glassfish.j2ee.statistics.TimeStatistic;
import com.sun.enterprise.admin.monitor.stats.AverageRangeStatistic;

/**
 *
 * @since 8.1
 */
public interface HAStatefulSessionStoreStats extends StatefulSessionStoreStats {
    
    /**
     * Returns the total number of sessions checkpointed using this store
     * @return CountStatistic
     */
    public CountStatistic getCheckpointCount();
    
    /**
     * Returns the total number of sessions successfully checkpointed using
     * this store
     * @return CountStatistic
     */
    public CountStatistic getCheckpointSuccessCount();
    
    /**
     * Returns the total number of sessions that could not be checkpointed
     * using this store
     * @return CountStatistic
     */
    public CountStatistic getCheckpointErrorCount();
    
    /**
     * Returns the total number of bytes checkpointed by the store
     * @return AverageRangeStatistic
     */
    public AverageRangeStatistic getCheckpointedBeanSize();
    
    /**
     * Returns the time spent on checkpointing beans to the store
     * @return AverageRangeStatistic
     */
    public AverageRangeStatistic getCheckpointTime();
    
}

==> payara-embedded-all-5.2021.4-sources.jar: com/sun/enterprise/admin/monitor/stats/HAStatefulSessionStoreStats.java <==
/*
 * DO NOT ALTER OR REMOVE COPYRIGHT NOTICES OR THIS HEADER.
 *
 * Copyright (c) 1997-2011 Oracle and/or its affiliates. All rights reserved.
 *
 * The contents of this file are subject to the terms of either the GNU
 * General Public License Version 2 only ("GPL") or the Common Development
 * and Distribution License("CDDL") (collectively, the "License").  You
 * may not use this file except in compliance with the License.  You can
 * obtain a copy of the License at
 * https://glassfish.dev.java.net/public/CDDL+GPL_1_1.html
 * or packager/legal/LICENSE.txt.  See the License for the specific
 * language governing permissions and limitations under the License.
 *
 * When distributing the software, include this License Header Notice in each
 * file and include the License file at packager/legal/LICENSE.txt.
 *
 * GPL Classpath Exception:
 * Oracle designates this particular file as subject to the "Classpath"
 * exception as provided by Oracle in the GPL Version 2 section of the License
 * file that accompanied this code.
 *
 * Modifications:
 * If applicable, add the following below the License Header, with the fields
 * enclosed by brackets [] replaced by your own identifying information:
 * "Portions Copyright [year] [name of copyright owner]"
 *
 * Contributor(s):
 * If you wish your version of this file to be governed by only the CDDL or
 * only the GPL Version 2, indicate your decision by adding "[Contributor]
 * elects to include this software in this distribution under the [CDDL or GPL
 * Version 2] license."  If you don't indicate a single choice of license, a
 * recipient has the option to distribute your version of this file under
 * either the CDDL, the GPL Version 2 or to extend the choice of license to
 * its licensees as provided above.  However, if you add GPL Version 2 code
 * and therefore, elected the GPL Version 2 license, then the option applies
 * only if the new code is made subject to such option by the copyright
 * holder.
 */
// Portions Copyright [2019] Payara Foundation and/or affiliates

package com.sun.enterprise.admin.monitor.stats;

import javax.management.j2ee.statistics.CountStatistic;

/**
 *
 * @since 8.1
 */
public interface HAStatefulSessionStoreStats extends StatefulSessionStoreStats {
    
    /**
     * Returns the total number of sessions checkpointed using this store
     * @return CountStatistic
     */
    public CountStatistic getCheckpointCount();
    
    /**
     * Returns the total number of sessions successfully checkpointed using
     * this store
     * @return CountStatistic
     */
    public CountStatistic getCheckpointSuccessCount();
    
    /**
     * Returns the total number of sessions that could not be checkpointed
     * using this store
     * @return CountStatistic
     */
    public CountStatistic getCheckpointErrorCount();
    
    /**
     * Returns the total number of bytes checkpointed by the store
     * @return AverageRangeStatistic
     */
    public AverageRangeStatistic getCheckpointedBeanSize();
    
    /**
     * Returns the time spent on checkpointing beans to the store
     * @return AverageRangeStatistic
     */
    public AverageRangeStatistic getCheckpointTime();
    
}
